LayoutWidget — pyqtgraph 0.11.0rc0 documentation

# LayoutWidget

class `pyqtgraph.` `LayoutWidget`(parent=None)

  Convenience class used for laying out QWidgets in a grid. (It’s just a little less effort to use than QGridLayout)

  `__init__`(parent=None)

    Initialize self. See help(type(self)) for accurate signature.

  `addLabel`(text=' ', row=None, col=None, rowspan=1, colspan=1, **kargs)

    Create a QLabel with text and place it in the next available cell (or in the cell specified) All extra keyword arguments are passed to QLabel(). Returns the created widget.

  `addLayout`(row=None, col=None, rowspan=1, colspan=1, **kargs)

    Create an empty LayoutWidget and place it in the next available cell (or in the cell specified) All extra keyword arguments are passed to `LayoutWidget.__init__` Returns the created widget.

  `addWidget`(item, row=None, col=None, rowspan=1, colspan=1)

    Add a widget to the layout and place it in the next available cell (or in the cell specified).

  `getWidget`(row, col)

    Return the widget in (row, col)

  `nextCol`(*args, **kargs)

    Alias of nextColumn

  `nextColumn`(colspan=1)

    Advance to next column, while returning the current column number (generally only for internal use–called by addWidget)

  `nextRow`()

    Advance to next row for automatic widget placement